@@ -361,83 +361,6 @@ extern "C" {
 	printMessages(status);
 	return R_NilValue;
     }
-/*  
-    void do_update(Console *console, int niter)
-    {
-	int width = 50;
-	int refresh = niter/width;
-
-	bool adapt = console->isAdapting();
-
-	if (refresh == 0) {
-	    refresh = 10;
-	    for (int n = niter; n > 0; n-=refresh) {
-		console->update(min2(n, refresh));
-		R_CheckUserInterrupt();
-	    }
-	    bool status = true;
-	    if (adapt) {
-		console->adaptOff(status);
-	    }
-	    if (!status) {
-		warning("Adaptation incomplete");
-	    }
-	    return;
-	}
-    
-	if (width > niter / refresh + 1) {
-	    width = niter / refresh + 1;
-        }
-
-        if (adapt) {
-	    Rprintf("Adapting %d\n", niter);
-        }
-        else {
-	    Rprintf("Updating %d\n", niter);
-        }
-	for (int i = 0; i < width - 1; ++i) {
-	    Rprintf("-");
-	}
-	Rprintf("| %d\n", min2(width * refresh, niter));
-    
-	int col = 0;
-	for (int n = niter; n > 0; n -= refresh) {
-	    int nupdate = min2(n, refresh);
-	    if(console->update(nupdate)) {
-                if (adapt) {
-		   Rprintf("+");
-                }
-                else {
-                   Rprintf("*");
-                }
-            }
-	    else {
-		Rprintf("\n");
-		printMessages(false);
-		return;
-	    }
-	    col++;
-	    if (col == width || n <= nupdate) {
-		int percent = 100 - (n-nupdate) * 100/niter;
-		Rprintf(" %d%%\n", percent); 
-		if (n > nupdate) {
-		    col = 0;
-		}
-	    }
-            R_CheckUserInterrupt();
-        }
-
-	bool status = true;
-	if (adapt) {
-	    // Turn off adaptive mode 
-	    console->adaptOff(status);
-	    adapt = false;
-	}
-	if (!status) {
-	    warning("Adaptation incomplete");
-	}
-    }
-*/
 
     SEXP is_adapting(SEXP ptr)
     {
